require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_firewall',
  dscmeta_resource_friendly_name: 'Firewall',
  dscmeta_resource_name: 'DSC_Firewall',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '9.0.0',
  docs: 'The DSC Firewall resource type.
         Automatically generated from version 9.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_description: {
      type: 'Optional[String]',
      desc: 'Documentation for the Rule.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_localonlymapping: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that matching firewall rules of the indicated value are created.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_localuser: {
      type: 'Optional[String]',
      desc: 'Specifies the principals to which network traffic this firewall rule applies.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_direction: {
      type: "Optional[Enum['Inbound', 'inbound', 'Outbound', 'outbound']]",
      desc: 'Direction of the connection.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_displayname: {
      type: 'Optional[String]',
      desc: 'Localized, user-facing name of the Firewall Rule being created.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: "Optional[Enum['True', 'true', 'False', 'false']]",
      desc: 'Enable or disable the supplied configuration.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_localport: {
      type: 'Optional[Array[String]]',
      desc: 'Local Port used for the filter.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_remoteaddress: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies that network packets with matching IP addresses match this rule.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_profile: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies one or more profiles to which the rule is assigned.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_action: {
      type: "Optional[Enum['NotConfigured', 'notconfigured', 'Allow', 'allow', 'Block', 'block']]",
      desc: 'Allow or Block the supplied configuration.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interfacetype: {
      type: "Optional[Enum['Any', 'any', 'Wired', 'wired', 'Wireless', 'wireless', 'RemoteAccess', 'remoteaccess']]",
      desc: 'Specifies that only network connections made through the indicated interface types are subject to the requirements of this rule.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_overrideblockrules: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that matching network traffic that would otherwise be blocked are allowed.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_displaygroup: {
      type: 'Optional[String]',
      desc: 'The current value of the Display Group of the Firewall Rule.',

      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_authentication: {
      type: "Optional[Enum['NotRequired', 'notrequired', 'Required', 'required', 'NoEncap', 'noencap']]",
      desc: 'Specifies that authentication is required on firewall rules.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_group: {
      type: 'Optional[String]',
      desc: 'Name of the Firewall Group where we want to put the Firewall Rule.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_encryption: {
      type: "Optional[Enum['NotRequired', 'notrequired', 'Required', 'required', 'Dynamic', 'dynamic']]",
      desc: 'Specifies that encryption in authentication is required on firewall rules.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_localaddress: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies that network packets with matching IP addresses match this rule.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_interfacealias: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the alias of the interface that applies to the traffic.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_program: {
      type: 'Optional[String]',
      desc: 'Path and file name of the program for which the rule is applied.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_platform: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies which version of Windows the associated rule applies.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_package: {
      type: 'Optional[String]',
      desc: 'Specifies the Windows Store application to which the firewall rule applies.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: 'Ensure the presence/absence of the resource.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_remoteuser: {
      type: 'Optional[String]',
      desc: 'Specifies that matching IPsec rules of the indicated user accounts are created.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_owner: {
      type: 'Optional[String]',
      desc: 'Specifies that matching firewall rules of the indicated owner are created.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_icmptype: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies the ICMP type codes.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_service: {
      type: 'Optional[String]',
      desc: 'Specifies the short name of a Windows service to which the firewall rule applies.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dynamictransport: {
      type: "Optional[Enum['Any', 'any', 'ProximityApps', 'proximityapps', 'ProximitySharing', 'proximitysharing', 'WifiDirectPrinting', 'wifidirectprinting', 'WifiDirectDisplay', 'wifidirectdisplay', 'WifiDirectDevices', 'wifidirectdevices']]",
      desc: 'Specifies a dynamic transport.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_remotemachine: {
      type: 'Optional[String]',
      desc: 'Specifies that matching IPsec rules of the indicated computer accounts are created.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_remoteport: {
      type: 'Optional[Array[String]]',
      desc: 'Specific Port used for filter. Specified by port number, range, or keyword',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_edgetraversalpolicy: {
      type: "Optional[Enum['Block', 'block', 'Allow', 'allow', 'DeferToUser', 'defertouser', 'DeferToApp', 'defertoapp']]",
      desc: 'Specifies that matching firewall rules of the indicated edge traversal policy are created.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_loosesourcemapping: {
      type: 'Optional[Boolean]',
      desc: 'Indicates that matching firewall rules of the indicated value are created.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Name of the Firewall Rule.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_protocol: {
      type: 'Optional[String]',
      desc: 'Specific Protocol for filter. Specified by name, number, or range.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
