require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_firewallprofile',
  dscmeta_resource_friendly_name: 'FirewallProfile',
  dscmeta_resource_name: 'DSC_FirewallProfile',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '9.0.0',
  docs: 'The DSC FirewallProfile resource type.
         Automatically generated from version 9.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_logmaxsizekilobytes: {
      type: 'Optional[Integer[0, 18446744073709551615]]',
      desc: 'Specifies the maximum file size of the log, in kilobytes. The acceptable values for this parameter are: 1 through 32767.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt64',
      mof_is_embedded: false,
    },
    dsc_defaultinboundaction: {
      type: "Optional[Enum['Block', 'block', 'Allow', 'allow', 'NotConfigured', 'notconfigured']]",
      desc: 'Specifies how to filter inbound traffic.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logfilename: {
      type: 'Optional[String]',
      desc: 'Specifies the path and filename of the file to which Windows Server writes log entries.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowlocalfirewallrules: {
      type: "Optional[Enum['True', 'true', 'False', 'false', 'NotConfigured', 'notconfigured']]",
      desc: 'Specifies that the local firewall rules should be merged into the effective policy along with Group Policy settings.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logblocked: {
      type: "Optional[Enum['True', 'true', 'False', 'false', 'NotConfigured', 'notconfigured']]",
      desc: 'Specifies how to log the dropped packets in the location specified by the LogFileName parameter.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_allowuserports: {
      type: "Optional[Enum['True', 'true', 'False', 'false', 'NotConfigured', 'notconfigured']]",
      desc: 'Specifies that traffic is allowed through local user ports.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowlocalipsecrules: {
      type: "Optional[Enum['True', 'true', 'False', 'false', 'NotConfigured', 'notconfigured']]",
      desc: 'Specifies that the local IPsec rules should be merged into the effective policy along with Group Policy settings.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logignored: {
      type: "Optional[Enum['True', 'true', 'False', 'false', 'NotConfigured', 'notconfigured']]",
      desc: 'Specifies how to log the ignored packets in the location specified by the LogFileName parameter.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enablestealthmodeforipsec: {
      type: "Optional[Enum['True', 'true', 'False', 'false', 'NotConfigured', 'notconfigured']]",
      desc: 'Enables stealth mode for IPsec traffic.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_notifyonlisten: {
      type: "Optional[Enum['True', 'true', 'False', 'false', 'NotConfigured', 'notconfigured']]",
      desc: 'Allows the notification of listening for inbound connections by a service.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: "Enum['Domain', 'domain', 'Public', 'public', 'Private', 'private']",
      desc: 'The name of the firewall profile to configure.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logallowed: {
      type: "Optional[Enum['True', 'true', 'False', 'false', 'NotConfigured', 'notconfigured']]",
      desc: 'Specifies how to log the allowed packets in the location specified by the LogFileName parameter.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_defaultoutboundaction: {
      type: "Optional[Enum['Block', 'block', 'Allow', 'allow', 'NotConfigured', 'notconfigured']]",
      desc: 'Specifies how to filter outbound traffic.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_disabledinterfacealiases: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies a list of interfaces on which firewall settings are excluded.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_allowunicastresponsetomulticast: {
      type: "Optional[Enum['True', 'true', 'False', 'false', 'NotConfigured', 'notconfigured']]",
      desc: 'Allows unicast responses to multi-cast traffic.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowuserapps: {
      type: "Optional[Enum['True', 'true', 'False', 'false', 'NotConfigured', 'notconfigured']]",
      desc: 'Specifies that traffic from local user applications is allowed through the firewall.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_enabled: {
      type: "Optional[Enum['True', 'true', 'False', 'false', 'NotConfigured', 'notconfigured']]",
      desc: 'Specifies that devolution is activated.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowinboundrules: {
      type: "Optional[Enum['True', 'true', 'False', 'false', 'NotConfigured', 'notconfigured']]",
      desc: 'Specifies that the firewall blocks inbound traffic.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
