require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_netadaptername',
  dscmeta_resource_friendly_name: 'NetAdapterName',
  dscmeta_resource_name: 'DSC_NetAdapterName',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '9.0.0',
  docs: 'The DSC NetAdapterName resource type.
         Automatically generated from version 9.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_macaddress: {
      type: 'Optional[String]',
      desc: 'This is the MAC address of the network adapter to find.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_driverdescription: {
      type: 'Optional[String]',
      desc: 'This is the driver description of the network adapter.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interfaceguid: {
      type: 'Optional[String]',
      desc: 'This is the interface GUID of the network adapter to find.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_physicalmediatype: {
      type: 'Optional[String]',
      desc: 'This is the media type of the network adapter to find.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'Optional[String]',
      desc: 'This is the name of the network adapter to find.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ignoremultiplematchingadapters: {
      type: 'Optional[Boolean]',
      desc: 'This switch will suppress an error occurring if more than one matching adapter matches the parameters passed.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_interfaceindex: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'This is the interface index of the network adapter to find.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_interfacenumber: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'This is the interface number of the network adapter if more than one are returned by the parameters.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_status: {
      type: "Optional[Enum['Up', 'up', 'Disconnected', 'disconnected', 'Disabled', 'disabled']]",
      desc: 'This is the status of the network adapter to find.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_newname: {
      type: 'String',
      desc: 'Specifies the new name of the network adapter.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interfacedescription: {
      type: 'Optional[String]',
      desc: 'This is the interface description of the network adapter to find.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
