require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_netipinterface',
  dscmeta_resource_friendly_name: 'NetIPInterface',
  dscmeta_resource_name: 'DSC_NetIPInterface',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '9.0.0',
  docs: 'The DSC NetIPInterface resource type.
         Automatically generated from version 9.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_advertising: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies the router advertisement value for the IP interface.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_automaticmetric: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies the value for automatic metric calculation.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_routerdiscovery: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled', 'ControlledByDHCP', 'controlledbydhcp']]",
      desc: 'Specifies the value for router discovery for an IP interface.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ecnmarking: {
      type: "Optional[Enum['Disabled', 'disabled', 'UseEct1', 'useect1', 'UseEct0', 'useect0', 'AppDecide', 'appdecide']]",
      desc: 'Specifies the value for Explicit Congestion Notification (ECN) marking.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ignoredefaultroutes: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies a value for Default Route advertisements.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_directedmacwolpattern: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies the wake-up packet value for an IP interface.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_managedaddressconfiguration: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies the value for managed address configuration.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_addressfamily: {
      type: "Enum['IPv4', 'ipv4', 'IPv6', 'ipv6']",
      desc: 'IP address family on the interface to configure.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_forwarding: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies the packet forwarding value for the IP interface.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interfacealias: {
      type: 'String',
      desc: 'Alias of the network interface to configure.',

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_weakhostsend: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies the send value for a weak host model.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_otherstatefulconfiguration: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies the value for configuration other than addresses.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interfacemetric: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the metric for an IP interface.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_advertisedefaultroute: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies the default router advertisement for an interface.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_weakhostreceive: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies the receive value for a weak host model.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_forcearpndwolpattern: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies the Wake On LAN (WOL) value for the IP interface.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_neighborunreachabilitydetection: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies the value for Neighbor Unreachability Detection (NUD).',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_nlmtu: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the network layer Maximum Transmission Unit (MTU) value, in bytes, for an IP interface.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
    dsc_dhcp: {
      type: "Optional[Enum['Enabled', 'enabled', 'Disabled', 'disabled']]",
      desc: 'Specifies the Dynamic Host Configuration Protocol (DHCP) value for an IP interface.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
