require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_proxysettings',
  dscmeta_resource_friendly_name: 'ProxySettings',
  dscmeta_resource_name: 'DSC_ProxySettings',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '9.0.0',
  docs: 'The DSC ProxySettings resource type.
         Automatically generated from version 9.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_timeout: {
      type:     'Optional[Integer]',
      desc:     'The maximum time in seconds to wait for the DSC resource to complete.',
      behaviour: :parameter,
    },
    dsc_target: {
      type: "Enum['LocalMachine', 'localmachine', 'CurrentUser', 'currentuser']",
      desc: "Specifies if the proxy settings should be set for the LocalMachine or for the CurrentUser. Defaults to 'LocalMachine'.",

      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',

      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_enableautodetection: {
      type: 'Optional[Boolean]',
      desc: "Enable automatic detection of the proxy settings. Defaults to 'False'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_enablemanualproxy: {
      type: 'Optional[Boolean]',
      desc: "Use manual proxy server settings. Defaults to 'False'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_proxyserver: {
      type: 'Optional[String]',
      desc: "The address and port of the manual proxy server to use. Should be specified if 'EnableManualProxy' is 'True'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'present', 'Absent', 'absent']]",
      desc: "Specifies if proxy settings should be set. Defaults to 'Present'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_proxyserverbypasslocal: {
      type: 'Optional[Boolean]',
      desc: "Bypass proxy server for local addresses. Defaults to 'False'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_proxyserverexceptions: {
      type: 'Optional[Array[String]]',
      desc: 'Bypass proxy server for addresses starting with addresses in this list.',


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_enableautoconfiguration: {
      type: 'Optional[Boolean]',
      desc: "Use automatic configuration script for specifying proxy settings. Defaults to 'False'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_connectiontype: {
      type: "Optional[Enum['All', 'all', 'Default', 'default', 'Legacy', 'legacy']]",
      desc: "Defines if the proxy settings should be configured for default connections, legacy connections or all connections. Defaults to 'All'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_autoconfigurl: {
      type: 'Optional[String]',
      desc: "The URL of the automatic configuration script to specify the proxy settings. Should be specified if 'EnableAutoConfiguration' is 'True'.",


      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
